package com.sun.tools.javac.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "25.0.1+8-LTS-jvmci-b01" },
            { "jdk", "25.0.1" },
            { "release", "25.0.1" },
        };
    }
}
